Struct shell_rs::ln::Options[][src]

pub struct Options {
    pub directory: bool,
    pub force: bool,
    pub logical: bool,
    pub no_dereference: bool,
    pub physical: bool,
    pub symbolic: bool,
}

Fields

directory: bool

Allow the superuser to attempt to hard link directories (note: will probably fail due to system restrictions, even for the supe‐ruser).

force: bool

Remove existing destination files.

logical: bool

Dereference TARGETs that are symbolic links.

no_dereference: bool

Treat LINK_NAME as a normal file if it is a symbolic link to a directory.

physical: bool

Make hard links directly to symbolic links.

symbolic: bool

Create symbolic links relative to link location.