Struct shell_rs::rm::RmOptions[][src]

pub struct RmOptions {
    pub recursive: bool,
    pub preserve_root: bool,
    pub one_file_system: bool,
    pub empty_dir: bool,
    pub expand_env: bool,
    pub use_glob: bool,
}

Fields

recursive: bool

Remove directories and their contenst recursively.

preserve_root: bool

Treat / specially.

one_file_system: bool

When removing a hierarchy recursively, skip any directory that is on a file system different from that of the corresponding argument.

empty_dir: bool

Remove empty directories.

expand_env: bool

Expand environment variables in path with expand_env().

use_glob: bool

Match shell style patterns in path.

Implementations