pub enum SyncMode {
Sync,
Filesystem,
File,
Data,
}
Sync all filesystem caches in system to disk.
Sync the file systems that contain the file.
Sync file data and metadata.
Sync only file data, no unneeded metadata.
Formats the value using the given formatter. Read more
This method tests for self and other values to be equal, and is used
by ==. Read more
This method tests for !=.
impl<T> Any for T where
T: 'static + ?Sized,
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
impl<T, U> Into<U> for T where
U: From<T>,
The type returned in the event of a conversion error.
The type returned in the event of a conversion error.