pub struct Options {
pub no_create: bool,
pub io_blocks: bool,
pub reference: Option<PathBuf>,
pub size: Option<String>,
}Fields
no_create: boolDo not create any files.
io_blocks: boolTreat size as number of IO blocks instead of bytes.
reference: Option<PathBuf>Base size on another file.
size: Option<String>Set or adjust the file size by size bytes.
The size argument is an integer and optional unit (example: 10K is 10*1024).
Units are K,M,G,T,P,E, (powers of 1024) or KB,MB,… (powers of 1000).
Binary prefixes can be used, too: KiB=K, MiB=M, and so on.
size may also be prefixed by one of the following modifying characters:
- ‘+’ extend by
- ‘-’ reduce by
- ‘<’ at most
- ‘>’ at least
- ‘/’ round down to multiple of
- ‘%’ round up to multiple of