Struct shell_rs::ln::Options [−][src]
pub struct Options {
pub directory: bool,
pub force: bool,
pub logical: bool,
pub no_dereference: bool,
pub physical: bool,
pub symbolic: bool,
}Fields
directory: boolAllow the superuser to attempt to hard link directories (note: will probably fail due to system restrictions, even for the supe‐ruser).
force: boolRemove existing destination files.
logical: boolDereference TARGETs that are symbolic links.
no_dereference: boolTreat LINK_NAME as a normal file if it is a symbolic link to a directory.
physical: boolMake hard links directly to symbolic links.
symbolic: boolCreate symbolic links relative to link location.